#python imports
from typing import Optional, List

#dependency imports
from entities.product import Product
from use_cases.product_repository import IProductRepository

class IViewAllProductsInputPort:
    def execute(self):
        """
        Abstract method to execute use case.
        """
        raise NotImplementedError("execute must be implemented by a subclass")
    
class IViewAllProductsOutputPort:
    def present(self, product_list:List[Product]):
        """
        Abstract method to execute use case.
        """
        raise NotImplementedError("execute must be implemented by a subclass")

class ViewAllProducts(IViewAllProductsInputPort):
    def __init__(self, product_repository: IProductRepository, output_port: IViewAllProductsOutputPort):
        self.product_repository = product_repository
        self.output_port = output_port

    def execute(self) -> Optional[List[Product]]:
        """
        Fetches the product data from the repository.
        """
        product_data = self.product_repository.get_all_products()
        if not product_data:
            return None
        return self.output_port.present(product_data)