#python imports
from typing import Optional

#dependency imports
from entities.product import Product
from use_cases.product_repository import IProductRepository

class IViewProductInputPort:
    def execute(self, product_id:int):
        """
        Abstract method to execute use case.
        """
        raise NotImplementedError("execute must be implemented by a subclass")
    
class IViewProductOutputPort:
    def present(self, product:Product):
        """
        Abstract method to execute use case.
        """
        raise NotImplementedError("execute must be implemented by a subclass")

class ViewProduct(IViewProductInputPort):
    def __init__(self, product_repository: IProductRepository, output_port: IViewProductOutputPort):
        self.product_repository = product_repository
        self.output_port = output_port

    def execute(self, product_id: int):
        """
        Fetches the product data from the repository.
        """
        product_data = self.product_repository.get_product_by_id(product_id)
        if not product_data:
            return None
            
        return self.output_port.present(product_data)